@@ -15,33 +15,37 @@
 """
 from zope.interface import Interface
 from zope.interface import implementer
-from zope.schema import BytesLine
+from zope.schema import NativeStringLine
 from zope.schema import Text
 
 from zope.configuration.config import GroupingContextDecorator
 from zope.configuration.interfaces import IConfigurationContext
 from zope.configuration.fields import GlobalObject
-from zope.configuration._compat import u
 
 
 class F(object):
     def __repr__(self):
         return 'f'
+
     def __call__(self, *a, **k):
-        pass
+        raise NotImplementedError
+
 
 f = F()
 
+
 class ISimple(Interface):
 
     a = Text()
     b = Text(required=False)
-    c = BytesLine()
+    c = NativeStringLine()
 
-def simple(context, a=None, c=None, b=u("xxx")):
+
+def simple(context, a=None, c=None, b=u"xxx"):
     return [(('simple', a, b, c), f, (a, b, c))]
 
-def newsimple(context, a, c, b=u("xxx")):
+
+def newsimple(context, a, c, b=u"xxx"):
     context.action(('newsimple', a, b, c), f, (a, b, c))
 
 
@@ -63,32 +67,29 @@ class IFactory(Interface):
 
     factory = GlobalObject()
 
+
 def factory(context, factory):
-    context.action(('factory', 1,2), factory)
+    context.action(('factory', 1, 2), factory)
+
 
 class Complex(object):
 
-    def __init__(self, context, a, c, b=u("xxx")):
+    def __init__(self, context, a, c, b=u"xxx"):
         self.a, self.b, self.c = a, b, c
         context.action("Complex.__init__")
 
     def factory(self, context, factory):
-        return [(('Complex.factory', 1,2), factory, (self.a, ))]
-
-    def factory2(self, context, factory):
-        return [(('Complex.factory', 1,2), factory, (self.a, ))]
+        return [(('Complex.factory', 1, 2), factory, (self.a, ))]
 
     def __call__(self):
-        return [(('Complex', 1,2), f, (self.b, self.c))]
+        return [(('Complex', 1, 2), f, (self.b, self.c))]
 
 
 class Ik(Interface):
-    for_ = BytesLine()
-    class_ = BytesLine()
-    x = BytesLine()
-    
+    for_ = NativeStringLine()
+    class_ = NativeStringLine()
+    x = NativeStringLine()
+
+
 def k(context, for_, class_, x):
     context.action(('k', for_), f, (for_, class_, x))
-
-def kkw(context, for_, class_, x, **kw):
-    context.action(('k', for_), f, (for_, class_, x, kw))
